@@ -10,7 +10,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(mimetype);
 our @EXPORT_OK = qw(extensions describe globs inodetype mimetype_canon mimetype_isa);
-our $VERSION = '0.28_03';
+our $VERSION = '0.29_01';
 our $DEBUG;
 
 our ($_hashed, $_hashed_aliases, $_hashed_subclasses);
@@ -243,10 +243,11 @@ sub _read_map_files {
 		next if grep {$_ eq $file} @done;
 		open MAP, '<', $file || croak "Could not open file '$file' for reading";
 		binmode MAP, ':utf8' unless $] < 5.008;
-		while (<MAP>) {
-			next if /^\s*#/ or ! /\S/; # skip comments and empty lines
-			chomp;
-			my ($k, $v) = split /\s+/, $_, 2;
+		while (my $line = <MAP>) {
+			next unless $line =~ m/\S/; # skip empty lines
+			next if $line =~ m/^\s*#/;  # skip comment lines
+			chomp $line;
+			my ($k, $v) = split m/\s+/, $line, 2;
 			if ($list) {
 				$map{$k} = [] unless $map{$k};
 				push @{$map{$k}}, $v;
@@ -453,6 +454,14 @@ in a straightforward manner only utf8 is supported (because the spec recommends
 This module does not yet check extended attributes for a mimetype.
 Patches for this are very welcome.
 
+This module uses the FreeDesktop.org shared mime info database. On your desktop
+linux this is typically pre-installed so it's not a problem. On your server
+you can install the shared-mime-info package via apt or dnf or apk or whatnot.
+
+To install on macOS, you can install it like this:
+
+    brew install shared-mime-info
+
 =head1 AUTHOR
 
 Jaap Karssenberg E<lt>pardus@cpan.orgE<gt>
